==> puppet-module-panko_15.4.0.orig.tar.xz: puppet-module-panko-15.4.0/spec/unit/type/panko_config_spec.rb <==
require 'puppet'
require 'puppet/type/panko_config'
describe 'Puppet::Type.type(:panko_config)' do
  before :each do
    @panko_config = Puppet::Type.type(:panko_config).new(:name => 'DEFAULT/foo', :value => 'bar')
  end

  it 'should require a name' do
    expect {
      Puppet::Type.type(:panko_config).new({})
    }.to raise_error(Puppet::Error, 'Title or name must be provided')
  end

  it 'should not expect a name with whitespace' do
    expect {
      Puppet::Type.type(:panko_config).new(:name => 'f oo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should fail when there is no section' do
    expect {
      Puppet::Type.type(:panko_config).new(:name => 'foo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should not require a value when ensure is absent' do
    Puppet::Type.type(:panko_config).new(:name => 'DEFAULT/foo', :ensure => :absent)
  end

  it 'should accept a valid value' do
    @panko_config[:value] = 'bar'
    expect(@panko_config[:value]).to eq('bar')
  end

  it 'should not accept a value with whitespace' do
    @panko_config[:value] = 'b ar'
    expect(@panko_config[:value]).to eq('b ar')
  end

  it 'should accept valid ensure values' do
    @panko_config[:ensure] = :present
    expect(@panko_config[:ensure]).to eq(:present)
    @panko_config[:ensure] = :absent
    expect(@panko_config[:ensure]).to eq(:absent)
  end

  it 'should not accept invalid ensure values' do
    expect {
      @panko_config[:ensure] = :latest
    }.to raise_error(Puppet::Error, /Invalid value/)
  end

  it 'should autorequire the package that install the file' do
    catalog = Puppet::Resource::Catalog.new
    package = Puppet::Type.type(:package).new(:name => 'panko')
    catalog.add_resource package, @panko_config
    dependency = @panko_config.autorequire
    expect(dependency.size).to eq(1)
    expect(dependency[0].target).to eq(@panko_config)
    expect(dependency[0].source).to eq(package)
  end


end

==> puppet-module-panko_18.4.0.orig.tar.xz: puppet-module-panko-18.4.0/spec/unit/type/panko_config_spec.rb <==
require 'puppet'
require 'puppet/type/panko_config'

describe 'Puppet::Type.type(:panko_config)' do
  before :each do
    @panko_config = Puppet::Type.type(:panko_config).new(:name => 'DEFAULT/foo', :value => 'bar')
  end

  it 'should require a name' do
    expect {
      Puppet::Type.type(:panko_config).new({})
    }.to raise_error(Puppet::Error, 'Title or name must be provided')
  end

  it 'should not expect a name with whitespace' do
    expect {
      Puppet::Type.type(:panko_config).new(:name => 'f oo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should fail when there is no section' do
    expect {
      Puppet::Type.type(:panko_config).new(:name => 'foo')
    }.to raise_error(Puppet::Error, /Parameter name failed/)
  end

  it 'should not require a value when ensure is absent' do
    Puppet::Type.type(:panko_config).new(:name => 'DEFAULT/foo', :ensure => :absent)
  end

  it 'should accept a valid value' do
    @panko_config[:value] = 'bar'
    expect(@panko_config[:value]).to eq('bar')
  end

  it 'should not accept a value with whitespace' do
    @panko_config[:value] = 'b ar'
    expect(@panko_config[:value]).to eq('b ar')
  end

  it 'should accept valid ensure values' do
    @panko_config[:ensure] = :present
    expect(@panko_config[:ensure]).to eq(:present)
    @panko_config[:ensure] = :absent
    expect(@panko_config[:ensure]).to eq(:absent)
  end

  it 'should not accept invalid ensure values' do
    expect {
      @panko_config[:ensure] = :latest
    }.to raise_error(Puppet::Error, /Invalid value/)
  end

  it 'should autorequire the package that install the file' do
    catalog = Puppet::Resource::Catalog.new
    anchor = Puppet::Type.type(:anchor).new(:name => 'panko::install::end')
    catalog.add_resource anchor, @panko_config
    dependency = @panko_config.autorequire
    expect(dependency.size).to eq(1)
    expect(dependency[0].target).to eq(@panko_config)
    expect(dependency[0].source).to eq(anchor)
  end


end
